# DataSynthesis131
Library to generate synthetic tabular data and evaluate quality of generated data.

# QualityEvaluator
A tool to evaluate sythetic data quality.

# Synthesizer
A tool to generate sythetic tabular data.


For more information and detailed instructions on how to use the QualityEvaluator or Synthesizer, please refer to the [README](https://github.com/MaratElagin/DataSynthesis131/blob/main/README.md) in our GitHub repository.

If you notice any inaccuracies, add issue [here](https://github.com/MaratElagin/DataSynthesis131/issues).